@@ -10,6 +10,6 @@ function(x, ...)
 function(x, axes = c(1:min(6, x$n.axes)), ...) {
   if (class(x) != "symcoca")
     stop("object must be of class \"symcoca\"")
-  score.dat <- scores(x, axes, extract = "site")$site
+  score.dat <- scores(x, axes, display = "site")
   diag(cor(score.dat$X1, score.dat$X2))
 }
